# Use rpmbuild --without gcj to disable native bits
%define with_gcj %{!?_without_gcj:1}%{?_without_gcj:0}

Name:          writer2latex
Version:       1.0.2
Release:       3%{?dist}
Summary:       Document Converter from ODT to LaTeX
License:       LGPLv2
Url:           http://writer2latex.sourceforge.net/
Source0:       http://writer2latex.svn.sourceforge.net/viewvc/writer2latex/tags/%{version}.tar.gz
Patch0:        writer2latex05.rh.patch
BuildRequires: ant, openoffice.org-core
Group:         Text Processing/Markup/XML
Buildroot:     %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires:      jaxp_parser_impl, jaxp_transform_impl
%if %{with_gcj}
BuildRequires: java-gcj-compat-devel >= 1.0.31
Requires(post): java-gcj-compat >= 1.0.31
Requires(postun): java-gcj-compat >= 1.0.31
%endif

%define baseinstdir %{_libdir}/openoffice.org

%description
Writer2LaTeX is a utility written in java. It converts OpenOffice.org documents
– in particular documents containing formulas – into other formats. It is
actually a collection of four converters, i.e.:
1) Writer2LaTeX converts documents into LaTeX 2e format for high quality
   typesetting.
2) Writer2BibTeX extracts bibliographic data from a document and stores it in
   BibTeX format (works together with Writer2LaTeX).
3) Writer2xhtml converts documents into XHTML 1.0 or XHTML 1.1+MathML 2.0 with
   CSS2.
4) Calc2xhtml is a companion to Writer2xhtml that converts OOo Calc documents
   to XHTML 1.0 with CSS2 to display your spreadsheets on the web.

%package javadoc
Summary:     Javadoc for %{name}
Group:       Development/Documentation
%if %{with_gcj}
BuildArch:    noarch
%endif

%description javadoc
Javadoc for %{name}.

%package -n openoffice.org-writer2latex
Summary:          OpenOffice.org Writer To LateX Converter
Group:            Applications/Productivity
Requires:         openoffice.org-core
Requires(pre):    openoffice.org-core
Requires(post):   openoffice.org-core
Requires(preun):  openoffice.org-core
Requires(postun): openoffice.org-core

%package -n openoffice.org-writer2xhtml
Summary:          OpenOffice.org Writer to xhtml Converter
Group:            Applications/Productivity
Requires:         openoffice.org-core
Requires(pre):    openoffice.org-core
Requires(post):   openoffice.org-core
Requires(preun):  openoffice.org-core
Requires(postun): openoffice.org-core

%description -n openoffice.org-writer2latex
Document Converter Extension for OpenOffice.org to provide 
LaTeX and BibTeX export filters.

%description -n openoffice.org-writer2xhtml
Document Converter Extension for OpenOffice.org to provide 
XHTML export filters.

%prep
%setup -q -n %{version}
%patch0 -p1 -b .rh.patch
sed -i -e 's#name="OFFICE_CLASSES" location="/usr/share/java/openoffice"#name="OFFICE_CLASSES" location="%{_libdir}/openoffice.org/basis3.3/program/classes"#' build.xml
sed -i -e 's#name="URE_CLASSES" location="/usr/share/java/openoffice"#name="URE_CLASSES" location="%{_libdir}/openoffice.org/ure/share/java"#' build.xml

%build
ant jar javadoc oxt

%install
rm -rf $RPM_BUILD_ROOT
# jar
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -p -m 644 target/lib/%{name}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} ${jar/-%{version}/}; done)
# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -p -r target/javadoc/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
pushd $RPM_BUILD_ROOT%{_javadocdir}
ln -s %{name}-%{version} %{name}
popd
# OOo extensions
install -d -m 755 $RPM_BUILD_ROOT%{baseinstdir}/extensions/writer2latex.oxt
unzip target/lib/writer2latex.oxt -d $RPM_BUILD_ROOT%{baseinstdir}/extensions/writer2latex.oxt
install -d -m 755 $RPM_BUILD_ROOT%{baseinstdir}/extensions/writer2xhtml.oxt
unzip target/lib/writer2xhtml.oxt -d $RPM_BUILD_ROOT%{baseinstdir}/extensions/writer2xhtml.oxt
%if %{with_gcj}
%{_bindir}/aot-compile-rpm
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%if %{with_gcj}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%postun
%if %{with_gcj}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%pre -n openoffice.org-writer2latex
if [ $1 -gt 1 ]; then
    # Upgrade
    # => deregister extension with old name if it exists
    unopkg remove --shared org.openoffice.legacy.writer2latex.uno.pkg > /dev/null 2>&1 || :
    # => deregister extension with new name if it exists
    unopkg remove --shared org.openoffice.da.writer2latex.oxt > /dev/null 2>&1 || :
fi

%pre -n openoffice.org-writer2xhtml
if [ $1 -gt 1 ]; then
    # Upgrade => deregister old extension
    unopkg remove --shared org.openoffice.da.writer2xhtml.oxt || :
fi

%files
%defattr(0644,root,root,0755)
%doc source/distro/History.txt source/distro/COPYING.TXT source/distro/Readme.txt source/distro/doc/user-manual.odt
%{_javadir}/*
%if %{with_gcj}
%attr(-,root,root) %{_libdir}/gcj/%{name}
%endif

%files javadoc
%defattr(0644,root,root,0755)
%doc source/distro/COPYING.TXT
%{_javadocdir}/%{name}
%{_javadocdir}/%{name}-%{version}

%files -n openoffice.org-writer2latex
%defattr(0644,root,root,0755)
%doc source/distro/COPYING.TXT
%{baseinstdir}/extensions/writer2latex.oxt

%files -n openoffice.org-writer2xhtml
%defattr(0644,root,root,0755)
%doc source/distro/COPYING.TXT
%{baseinstdir}/extensions/writer2xhtml.oxt

%changelog
* Wed Jul 14 2010 Caolán McNamara <caolanm@redhat.com> 1.0.2-3
- rebuild for OpenOffice.org 3.3

* Thu Jul 08 2010 Caolán McNamara <caolanm@redhat.com> 1.0.2-2
- add COPYING to all subpackages

* Sat Jun 05 2010 Caolán McNamara <caolanm@redhat.com> 1.0.2-1
- latest version

* Tue Mar 09 2010 Caolán McNamara <caolanm@redhat.com> 1.0.1-1
- latest version

* Mon Dec 21 2009 Caolán McNamara <caolanm@redhat.com> 1.0-3
- Preserve time stamps

* Thu Nov 19 2009 Caolán McNamara <caolanm@redhat.com> 1.0-2
- Resolves: rhbz#539035 update for OOo 3.2

* Mon Sep 21 2009 Caolán McNamara <caolanm@redhat.com> 1.0-1
- latest version

* Fri Jul 24 2009 Caolán McNamara <caolanm@redhat.com> 0.5.0.2-7
- make javadoc no-arch when building as arch-dependant aot

* Thu Feb 26 2009 Caol@n McNamara <caolanm@redhat.com> 0.5.0.2-6
- update for 3.1

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Nov 23 2008 Caolán McNamara <caolanm@redhat.com> 0.5.0.2-4
- tweak summary

* Thu Nov 20 2008 Caolán McNamara <caolanm@redhat.com> 0.5.0.2-3
- upstream repacked tarballs to replace 0.5.0.1 with 0.5.0.2

* Mon Oct 06 2008 Caolán McNamara <caolanm@redhat.com> 0.5.0.2-2
- update for guidelines

* Wed Sep 03 2008 Caolán McNamara <caolanm@redhat.com> 0.5.0.2-1
- latest version

* Sat Aug 09 2008 Caolán McNamara <caolanm@redhat.com> 0.5-4
- use generic requires

* Sat Mar 31 2008 Caolán McNamara <caolanm@redhat.com> 0.5-3
- tweak for guidelines
- and adjust for OOo3 3 layer packaging

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.5-2
- Autorebuild for GCC 4.3

* Sun Dec 1 2007 Caolán McNamara <caolanm@redhat.com> 0.5-1
- initial version
